@@ -10,7 +10,8 @@ def parse_config(template="config.ini"):
     # Read the config.
     cp = ConfigParser()
     try:
-        return cp.read(config_path)
-    except Exception:
+        cp.read(config_path)
+    except FileNotFoundError:
         copyfile(config_example_path, config_path)
-        return cp.read(config_path)
+        cp.read(config_path)
+    return cp
\ No newline at end of file
